@@ -10,7 +10,8 @@
 #'
 #' @param date Numeric. Date of the data in the format `yyyymm`. Defaults to
 #'             `202001`. To download the data for all months in a year, the user
-#'             can pass a 4-digit year input `yyyy`.
+#'             can pass a 4-digit year input `yyyy`. The parameter also accepts
+#'             a vector of dates such as `c(202001, 20206, 202012)`.
 #' @param type String. Whether the data set should be of the type `basica`
 #'             (flight stage, the default) or `combinada` (On flight origin and
 #'             destination - OFOD).
@@ -29,7 +30,10 @@
 #'
 #' f2015 <- read_flights(date = 2015)
 #'}}
-read_flights <- function(date = 202001, type = 'basica', showProgress = TRUE, select = NULL){
+read_flights <- function(date = 202001,
+                         type = 'basica',
+                         showProgress = TRUE,
+                         select = NULL){
 
 ### check inputs
   if( ! type %in% c('basica', 'combinada') ){ stop(paste0("Argument 'type' must be either 'basica' or 'combinada'")) }
@@ -46,8 +50,9 @@ read_flights <- function(date = 202001, type = 'basica', showProgress = TRUE, se
   check_date(date=date, all_dates)
 
 
-if (nchar(date)==6) {
+
 #### Download one month---------------------------------------------------------
+if (length(date) == 1 & nchar(date[1])==6) {
 
 # prepare address of online data
   # split date into month and year
@@ -56,16 +61,26 @@ if (nchar(date)==6) {
   file_url <- get_flights_url(type=type, year=y, month=m)
 
 # download and read data
-  dt <- download_flights_data(file_url, showProgress = showProgress, select = select)
+  dt <- download_flights_data(file_url,
+                              showProgress = showProgress,
+                              select = select)
 
   # check if download failed
   if (is.null(dt)) { return(invisible(NULL)) }
 
   return(dt)
+}
+
+
+
+  # set pbapply options
+  original_options <- pbapply::pboptions()
+  if( showProgress==FALSE){ pbapply::pboptions(type='none') }
+  if( showProgress==TRUE){ pbapply::pboptions(type='txt' ,char='=') }
 
 
-} else if (nchar(date)==4) {
 #### Download whole year---------------------------------------------------------
+if (length(date) == 1 & nchar(date[1])==4) {
 
 # prepare address of online data
 all_months <- generate_all_months(date)
@@ -73,14 +88,10 @@ all_months <- generate_all_months(date)
 # ignore dates after max(all_dates)
 all_months <- all_months[all_months <= max(all_dates)]
 
-# set pbapply options
-original_options <- pbapply::pboptions()
-if( showProgress==FALSE){ pbapply::pboptions(type='none') }
-if( showProgress==TRUE){ pbapply::pboptions(type='txt' ,char='=') }
-
 # download data
 dt_list <- pbapply::pblapply( X=all_months,
-                   FUN= function(i, type.=type, showProgress.=FALSE, select.=select) { # i = all_months[3]
+                   FUN= function(i, type.=type, showProgress.=FALSE,
+                                 select.=select) { # i = all_months[3]
 
                       # prepare address of online data
                       # split date into month and year
@@ -90,13 +101,27 @@ dt_list <- pbapply::pblapply( X=all_months,
                       file_url <- get_flights_url(type=type, year=y, month=m)
 
                       # download and read data
-                      temp_dt <- download_flights_data(file_url, showProgress = FALSE, select = select)
+                      temp_dt <- download_flights_data(file_url,
+                                                       showProgress = FALSE,
+                                                       select = select)
 
                       # check if download failed
                       if (is.null(temp_dt)) { return(invisible(NULL)) }
                       return(temp_dt)
                       }
                    )
+}
+#### Download a vector of dates-------------------------------------------------
+if (length(date)>1) {
+
+  dt_list <- lapply(X = date,
+                    FUN = function(x){read_flights(date = x,
+                                                   type = type,
+                                                   showProgress = showProgress,
+                                                   select = select)
+                    }
+                  )
+}
 
 # return to original pbapply options
 pbapply::pboptions(original_options)
@@ -104,6 +129,5 @@ pbapply::pboptions(original_options)
 # row bind data tables
 dt <- data.table::rbindlist(dt_list)
 return(dt)
-
-}}
+}
 
